REPL loop and command handling for OpenDev.
This crate provides:
repl— Main REPL loop: read input -> process -> displayquery_processor— Process user queries, enhance with context, delegate to ReActtool_executor— Execute tools and format resultscommands— Slash command routing and built-in commandserror— Error types
Re-exports
pub use error::ReplError;pub use handlers::HandlerRegistry;pub use query_enhancer::QueryEnhancer;pub use query_processor::QueryProcessor;pub use repl::Repl;pub use skills::Skill;pub use skills::list_cached_skills;pub use skills::load_skill_from_file;pub use skills::load_skill_from_url;pub use tool_executor::ToolExecutor;
Modules
- commands
- Slash command module.
- error
- Error types for the REPL crate.
- file_
injector - File content injection for
@mentions with structured XML tags. - handlers
- Tool handler middleware layer.
- query_
enhancer - Query enhancement and message preparation for the REPL.
- query_
processor - Process user queries, enhance with context, delegate to ReAct loop.
- repl
- Main REPL loop: read input -> process -> display.
- skills
- Skill loading from remote URLs and local cache.
- tool_
executor - Execute tools and format results.